package eu.etaxonomy.taxeditor.prototype2.view.nameviewersupport;

import org.eclipse.core.runtime.Assert;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.KeyListener;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.prototype2.controller.ActionAddSynonymToTaxon;

/**
 * The only purpose of this listener is to catch carriage returns
 *  at end-of-line, and create new empty name viewers.
 *  
 * Carriage returns in the middle of a line are caught by
 *  NameViewerModifyListener. 
 * 
 * @author p.ciardelli
 *
 */
public class NameViewerKeyListener implements KeyListener {

	private Taxon taxon;
	
	public NameViewerKeyListener(Taxon taxon) {
		
		Assert.isNotNull(taxon);
		this.taxon = taxon;
	}

	public void keyPressed(KeyEvent e) {
		StyledText sText = (StyledText) e.widget;
				
		// If user has pressed carriage return at EOL,
		//  the modifyListener doesn't catch it -
		//  make new source viewer
		if (e.character == SWT.CR && 
				sText.getCaretOffset() == sText.getText().length()) {
			new ActionAddSynonymToTaxon(taxon, "").run();
		}
	}
	public void keyReleased(KeyEvent e) { }
}
