/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.datasource;

import java.util.List;

import eu.etaxonomy.cdm.api.application.CdmApplicationController;
import eu.etaxonomy.cdm.database.CdmPersistentDataSource;
import eu.etaxonomy.cdm.database.DatabaseTypeEnum;
import eu.etaxonomy.cdm.database.ICdmDataSource;

/**
 * @author p.ciardelli
 * @created 11.12.2008
 * @version 1.0
 */
public interface ICdmDataSourceRepository {
	
	/**
	 * Get a list of all CDM dataSources associated
	 * with this session of the Taxonomic Editor, persistent
	 * or otherwise.
	 * 
	 * @return
	 */
	public List<ICdmDataSource> getAll();
	
	/**
	 * Add <code>dataSource</code> to the list of all
	 * CDM dataSources associated with this session
	 * of the Taxonomic Editor. 
	 * 
	 * @param dataSource
	 * @return
	 */
	public boolean add(ICdmDataSource dataSource);
	
	/**
	 * If <code>dataSourceName</code> already exists as persistent CDM
	 * dataSources, it is updated with parameter values.
	 * <p>
	 * If it does not exist, <code>dataSource</code> will be created. 
	 * 
	 * @param dataSourceName
	 * @param databaseType
	 * @param server
	 * @param database
	 * @param port
	 * @param username
	 * @param password
	 * @return
	 */
	public CdmPersistentDataSource save(String dataSourceName, DatabaseTypeEnum databaseType, String server, String database, 
			int port, String username, String password);

	/**
	 * Almost identical to {@link #save(String,DatabaseTypeEnum,String,String,int,String,String)}, 
	 * except it does not take a <code>port</code>.
	 * 
	 * @param dataSourceName
	 * @param databaseType
	 * @param server
	 * @param database
	 * @param username
	 * @param password
	 * @return
	 */
	public CdmPersistentDataSource save(String dataSourceName, DatabaseTypeEnum databaseType, String server, String database, 
			String username, String password);
	
	/**
	 * Remove <code>dataSource</code> from the list of all
	 * CDM dataSources associated with this session
	 * of the Taxonomic Editor. 
	 * 
	 * @param dataSource
	 * @return
	 */	
	public boolean remove(ICdmDataSource dataSource);

	/**
	 * Remove <code>dataSource</code> from the list of all
	 * <i>persistent</i> CDM dataSources associated with this 
	 * Taxonomic Editor.
	 *  
	 * @param dataSource
	 * @return
	 */
	public boolean delete(CdmPersistentDataSource dataSource);
	
	/**
	 * All data source operations run through a <code>CdmApplicationController</code>.
	 * 
	 * @param cdmAppController
	 */
	public void setCdmApplicationController(CdmApplicationController cdmAppController);
	
	/**
	 * Get the data source currently associated with this
	 * Taxonomic Editor.
	 * 
	 * @return
	 */
	public ICdmDataSource getCurrentDataSource();
	
	/**
	 * Set <code>dataSource</code> as this Taxonomic Editor's
	 * current data source.
	 * 
	 * @param dataSource
	 * @return
	 */
	public boolean setCurrentDataSource(ICdmDataSource dataSource);
}
