// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor;

import java.util.UUID;

import org.apache.log4j.Logger;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.ui.IElementFactory;
import org.eclipse.ui.IMemento;

import eu.etaxonomy.taxeditor.store.CdmStore;


/**
 * @author p.ciardelli
 * @created 23.04.2009
 * @version 1.0
 */
public class TaxonEditorInputFactory implements IElementFactory {
	private static final Logger logger = Logger
			.getLogger(TaxonEditorInputFactory.class);

    /**
     * Factory id. The workbench plug-in registers a factory by this name
     * with the "org.eclipse.ui.elementFactories" extension point.
     */
    private static final String ID_FACTORY = "eu.etaxonomy.taxeditor.editor.TaxonEditorInputFactory"; //$NON-NLS-1$
	
    /**
     * Tag for the IFile.fullPath of the file resource.
     */
    private static final String TAXON_UUID = "uuid"; //$NON-NLS-1$
    
	/* (non-Javadoc)
	 * @see org.eclipse.ui.IElementFactory#createElement(org.eclipse.ui.IMemento)
	 */
	public IAdaptable createElement(IMemento memento) {
        // Get the uuid
        String uuid = memento.getString(TAXON_UUID);
        if (uuid == null) {
			return null;
		}
        if (CdmStore.getTaxonService().getTaxonByUuid(UUID.fromString(uuid)) == null) {
        	logger.warn("Couldn't find taxon with UUID " + uuid);
        	return null;
        }
        logger.info("Creating taxon from memento w UUID " + uuid);
        return TaxonEditorInput.NewInstance(UUID.fromString(uuid));
	}
	
    /**
     * Returns the element factory id for this class.
     * 
     * @return the element factory id
     */
    public static String getFactoryId() {
        return ID_FACTORY;
    }
    
    /**
     * Saves the state of the given file editor input into the given memento.
     *
     * @param memento the storage area for element state
     * @param input the file editor input
     */
    public static void saveState(IMemento memento, TaxonEditorInput input) {
    	String uuid = input.getTaxon().getUuid().toString();
        memento.putString(TAXON_UUID, uuid);
    }
}