package eu.etaxonomy.taxeditor.editor;

import org.eclipse.swt.dnd.ByteArrayTransfer;
import org.eclipse.swt.dnd.TransferData;
import org.eclipse.swt.widgets.Widget;

/**
 * For drag and drop - a drag widget with this transfer type can only be dropped onto
 *  a drop widget with the same type.
 *    
 * @author p.ciardelli
 *
 */
public class WidgetTransfer extends ByteArrayTransfer {

	private static final String WIDGETTYPENAME = "widget_type";
	private static final int WIDGETTYPEID = registerType (WIDGETTYPENAME);		
	private static final WidgetTransfer INSTANCE = new WidgetTransfer();
	
	/*
	 * The object associated with this transfer event
	 */
	private Widget widget;
		
	/*
	 * Returns the singleton
	 */
	public static WidgetTransfer getInstance() {
		return INSTANCE;
	}
	/*
	 * Set transfer data for local use
	 */
	public void setWidget(Widget widget) {
		this.widget = widget;
	}
	/*
	 * Returns the local transfer data
	 */
	public Widget getWidget() {
		return widget;
	}
	
	/* 
	 * The type ID is used to identify this transfer
	 */
	@Override
	protected int[] getTypeIds() {
		return new int[] { WIDGETTYPEID };
	}

	@Override
	protected String[] getTypeNames() {
		return new String[] { WIDGETTYPENAME } ;
	}

	@Override
	protected void javaToNative(Object object, TransferData transferData) {
		// No encoding needed since this is a hardcoded string read and written
		// in the same process.
		// See nativeToJava below
		byte[] check = WIDGETTYPENAME.getBytes();
		super.javaToNative(check, transferData);
	}

	@Override
	protected Object nativeToJava(TransferData transferData) {
		Object result = super.nativeToJava(transferData);
		if (isInvalidNativeType(result)) {
			throw new RuntimeException(); //$NON-NLS-1$
		}
		return widget;
	}
	
	private boolean isInvalidNativeType(Object result) {
		// No encoding needed since this is a hardcoded string read and written
		// in the same process.
		// See javaToNative above
		return !(result instanceof byte[])
				|| !WIDGETTYPENAME.equals(new String((byte[]) result));
	}
}
