// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.description;

import java.awt.Color;
import java.util.Map;
import java.util.Set;

import org.eclipse.swt.SWT;
import org.eclipse.swt.browser.Browser;
import org.eclipse.swt.browser.ProgressEvent;
import org.eclipse.swt.browser.ProgressListener;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.events.ControlListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Dialog;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.ProgressBar;
import org.eclipse.swt.widgets.Shell;

import eu.etaxonomy.cdm.ext.EditGeoService;
import eu.etaxonomy.cdm.model.description.Distribution;
import eu.etaxonomy.cdm.model.description.PresenceAbsenceTermBase;
import eu.etaxonomy.taxeditor.editor.AbstractTaxonEditor;

/**
 * @author n.hoffmann
 * @created 26.05.2009
 * @version 1.0
 */
public class DistributionMapDialog extends Dialog {

	private Set<Distribution> distributions;

	private AbstractTaxonEditor editor;

	private Browser browser;

	private Shell shell;
	
	/**
	 * @param parent
	 * @param style
	 */
	public DistributionMapDialog(Shell parent, int style) {
		super(parent, style);
		this.setText("Map Viewer");
	}
	
	/**
	 * @param parent
	 */
	public DistributionMapDialog(AbstractTaxonEditor editor, Shell parent, Set<Distribution> distributions) {
		this(parent, 0);
		
		this.editor = editor;
		this.distributions = distributions;
	}

	public Object open () {
		Shell parent = getParent();
		shell = new Shell(parent, SWT.DIALOG_TRIM | SWT.MAX | SWT.RESIZE | SWT.APPLICATION_MODAL);
		shell.setText(getText());
		
		shell.setSize(810, 450);

		
//		Composite composite = new Composite(shell, SWT.NONE);
		
		GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 1;
		shell.setLayout(gridLayout);
		
		browser = new Browser(shell, SWT.NONE);
		
		GridData data = new GridData();
		data.horizontalAlignment = GridData.FILL;
		data.verticalAlignment = GridData.FILL;
		data.grabExcessHorizontalSpace = true;
		data.grabExcessVerticalSpace = true;
		
		browser.setLayoutData(data);
		
		
		final ProgressBar progressBar = new ProgressBar(shell, SWT.NONE);
		data = new GridData();
		data.horizontalAlignment = GridData.END;
		progressBar.setLayoutData(data);
		

		browser.addProgressListener(new ProgressListener() {
			public void changed(ProgressEvent event) {
					if (event.total == 0) return;                            
					int ratio = event.current * 100 / event.total;
					progressBar.setSelection(ratio);
			}
			public void completed(ProgressEvent event) {
				progressBar.setSelection(0);
			}
		});
		
		shell.addControlListener(new ControlListener(){

			public void controlMoved(ControlEvent e) {
				// do nothing
			}

			public void controlResized(ControlEvent e) {
				loadMap();
			}
			
		});
		
		shell.open();
		loadMap();
		
		Display display = parent.getDisplay();
		while (!shell.isDisposed()) {
			if (!display.readAndDispatch()) display.sleep();
		}
		return null;
	}
	
	private void loadMap(){
		browser.setUrl(getMapUrl());
	}
	
	private String getMapUrl(){
		// FIXME make these hardcoded parameters configurable via preferences
		String url = "http://edit.csic.es/v1/areas.php";
		Map<PresenceAbsenceTermBase<?>,Color> presenceAbsenceTermColors = null;
		int width = calculateWidth();
		int height = 0; 
		String bbox = "-180,-90,180,90"; 
		String backLayer = null;
		
		String parameter = EditGeoService.getEditGeoServiceUrlParameterString(
				distributions, 
				presenceAbsenceTermColors, 
				width, 
				height, 
				bbox, 
				backLayer);
		
		return url + "?" + parameter;
	}

	/**
	 * @return
	 */
	private int calculateWidth(){
		return shell.getSize().x - 10;
	}
	
	/**
	 * @return the editor
	 */
	public AbstractTaxonEditor getEditor() {
		return editor;
	}
}
