// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.images;

import java.net.URI;
import java.net.URISyntaxException;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.FocusAdapter;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.PaintEvent;
import org.eclipse.swt.events.PaintListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Canvas;
import org.eclipse.ui.forms.widgets.TableWrapData;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.media.ImageFile;
import eu.etaxonomy.taxeditor.editor.CompositeBorderDecorator;
import eu.etaxonomy.taxeditor.editor.GroupComposite;
import eu.etaxonomy.taxeditor.editor.GroupedComposite;
import eu.etaxonomy.taxeditor.editor.name.AcceptedNameComposite;
import eu.etaxonomy.taxeditor.propertysheet.images.ImagePropertySource;
import eu.etaxonomy.taxeditor.store.model.ImageResources;

/**
 * @author p.ciardelli
 * @created 30.03.2009
 * @version 1.0
 */
public class ImageComposite extends GroupedComposite {	

	protected Image image;
	
	private Canvas canvas;

	private FocusAdapter focusListener;

	private ImageFile imageFile;
	
	/**
	 * @param groupComposite
	 * @param form
	 * @param taxon
	 * @param url
	 */
	public ImageComposite(TaxonImageEditor editor, GroupComposite groupComposite, ImageFile imageFile) {
		super(editor, groupComposite);
		
		
		
		this.imageFile = imageFile;
		
		setIsDraggable(false);
//		setIcon(AcceptedNameComposite.ACCEPTED_ICON);
		setIndent(AcceptedNameComposite.ACCEPTED_INDENT);

		createImage(imageFile);
		
		this.setMenu(editor.getMenu());
		
		createBorderSupport();
		
	}
	
	protected void createControl() {
		super.createControl();
				
		Color groupBackgroundColor = getDisplay().getSystemColor(SWT.COLOR_WHITE);
		setBackground(groupBackgroundColor);
	}
	
	/**
	 * @param url
	 */
	private void createImage(ImageFile imageFile) {
		
		URI uri = null;

		// TODO ImageFile.getUri should return a URI
		try {
			uri = new URI(imageFile.getUri());
		} catch (URISyntaxException e1) {
			// TODO this should never happen
			e1.printStackTrace();
		}
		
		
		image = ImageResources.getImage(uri);
		
		// Not optimal - why should getting composite to size to img be so obtuse?! 
//		canvas = new Canvas(this, SWT.NO_REDRAW_RESIZE);
		canvas = new Canvas(this, SWT.NONE);
		
		TableWrapData layoutData = new TableWrapData(TableWrapData.LEFT, TableWrapData.TOP);
		layoutData.heightHint = image.getBounds().height;
		canvas.setLayoutData(layoutData);
		
		canvas.addPaintListener (new PaintListener () {
			public void paintControl (PaintEvent e) {
				if (image != null) {
					canvas.setBounds(image.getBounds());
					e.gc.drawImage (image, 0, 0);
				}
			}
		});
		
		canvas.setBounds(image.getBounds());	
		
		focusListener = new FocusAdapter() {
			public void focusGained(FocusEvent e) {
				setFocus();
			}
		};
		canvas.addFocusListener(focusListener);
	}


	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.GroupedComposite#getViewerFont()
	 */
	@Override
	protected Font getViewerFont() {
		return null;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.IHasPropertySource#getPropertySource()
	 */
	public IPropertySource getPropertySource() {
		return new ImagePropertySource(getTaxon(), imageFile);
	}
	
	public void createBorderSupport() {
		
		CompositeBorderDecorator borderDecorator = new CompositeBorderDecorator(
				canvas, managedForm);
		setBorderDecorator(borderDecorator);
		borderDecorator.setLoseFocus(false);
		this.addFocusListener(borderDecorator);

	}
	
	public void dispose () {
		super.dispose();
		
		if (getBorderDecorator() != null) {
			this.removeFocusListener(getBorderDecorator());
		}
		
		if (image != null) {
			image.dispose();
		}
	}
}
