// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.images;

import org.apache.log4j.Logger;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Event;
import org.eclipse.ui.handlers.IHandlerService;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.taxeditor.editor.GroupComposite;
import eu.etaxonomy.taxeditor.editor.GroupedComposite;
import eu.etaxonomy.taxeditor.editor.internal.TaxeditorEditorPlugin;
import eu.etaxonomy.taxeditor.editor.name.NameComposite;
import eu.etaxonomy.taxeditor.editor.name.NameViewer;

/**
 * @author p.ciardelli
 * @created 31.03.2009
 * @version 1.0
 */
public class TaxonHasNoImagesComposite extends GroupedComposite {
	private static final Logger logger = Logger
			.getLogger(TaxonHasNoImagesComposite.class);

	/**
	 * @param groupComposite
	 * @param form
	 * @param taxon
	 */
	public TaxonHasNoImagesComposite(TaxonImageEditor editor, GroupComposite parent) {
		super(editor, parent);

		createTextViewer();
		setIsDraggable(false);
//		setIcon(ACCEPTED_ICON);
		setFont(getViewerFont());
//		setIndent(ACCEPTED_INDENT);

		initEmptyText();
	}

	protected void createControl() {
		super.createControl();
				
		Color groupBackgroundColor = getDisplay().getSystemColor(SWT.COLOR_WHITE);
		setBackground(groupBackgroundColor);
	}
	
	protected void initEmptyText() {
		super.initEmptyText();
		
		getTextViewer().getTextWidget().setEditable(false);
		getTextViewer().getTextWidget().addMouseListener(new MouseAdapter() {
			public void mouseUp(MouseEvent e) {
				createNewImage();
			}
		});
		
		if (getTextViewer() instanceof NameViewer) {
			Color groupBackgroundColor = getDisplay().getSystemColor(SWT.COLOR_WHITE);
			((NameViewer) getTextViewer()).setBackground(groupBackgroundColor);
		}
	}
	
	protected String getEmptyTextPrompt() {
		return "Click to add an image"; 
	}
	
	/**
	 * 
	 */
	private void createNewImage() {
		IHandlerService handlerService = (IHandlerService) TaxeditorEditorPlugin.getDefault().getWorkbench().getService(IHandlerService.class);
		
		String commandId = "eu.etaxonomy.taxeditor.editor.name.createImage";
		Event event = new Event();
		try {
			handlerService.executeCommand(commandId, event);
		} catch (Exception e) {
			logger.error("Error executing CreateImageHandler", e);
		} 
	}


	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.GroupedComposite#getViewerFont()
	 */
	@Override
	protected Font getViewerFont() {
		return NameComposite.ACCEPTED_FONT;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.IHasPropertySource#getPropertySource()
	 */
	public IPropertySource getPropertySource() {
		return null;
	}
}
