// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.images;

import java.util.HashSet;
import java.util.Set;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.PartInitException;

import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.media.ImageFile;
import eu.etaxonomy.taxeditor.editor.AbstractTaxonEditor;
import eu.etaxonomy.taxeditor.editor.FreeTextElementFactory;
import eu.etaxonomy.taxeditor.editor.GroupComposite;
import eu.etaxonomy.taxeditor.editor.GroupedComposite;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.store.model.ImagesUtil;

/**
 * @author p.ciardelli
 * @author n.hoffmann
 * @created 30.03.2009
 * @version 1.0
 */
public class TaxonImageEditor extends AbstractTaxonEditor {
		
	private static final String ID = "eu.etaxonomy.taxeditor.taxonImageEditor";

	private TaxonDescription emptyGallery; 
	
	public TaxonImageEditor(MultiPageTaxonEditor editor){
		super(editor);
	}
	
	public void init(IEditorSite site, IEditorInput input)
			throws PartInitException {
				
		super.init(site, input);
	}
	
	@Override
	protected void createManagedForm(Composite composite) {
		
		super.createManagedForm(composite);
		
		Set<TaxonDescription> descriptions = taxon.getDescriptions();
		Set<DescriptionBase<?>> imageGalleries = new HashSet<DescriptionBase<?>>();
		
		for(TaxonDescription description : descriptions){
			if(description.isImageGallery()){
				imageGalleries.add(description);
			}
		}
		
		
		if(imageGalleries.size() == 0){
			emptyGallery = TaxonDescription.NewInstance();
			emptyGallery.setImageGallery(true);
			emptyGallery.setTitleCache("");
			descriptions.add(emptyGallery);
			

			taxon.addDescription(emptyGallery);
		}
		
		firstGroupedComposite = null;
		
		for(DescriptionBase<?> description : descriptions){
			if(description.isImageGallery()){
				// Draw gallery label
				Composite labelComposite = 
					FreeTextElementFactory.getDefault().createGalleryLabel(this, (TaxonDescription) description);
				
				// Note whether this is the first label drawn
				if (firstGroupedComposite == null) {
					firstGroupedComposite = (GroupedComposite) labelComposite;
				}
				
				Set<ImageFile> imageFiles = ImagesUtil.getImages((TaxonDescription) description);
				
				for(ImageFile imageFile : imageFiles){
					FreeTextElementFactory.getDefault().createImageElement(this, imageFile);
				}
			}
		}

		// Redraw composite
		composite.layout();
	}

	/**
	 * @return
	 */
	public GroupComposite getImageGroup() {
		for(Composite c : getGroupedComposites()){
			if(c instanceof ImagesGroupComposite){
				return (GroupComposite) c;
			}
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.AbstractTaxonEditor#getID()
	 */
	@Override
	public String getID() {
		return TaxonImageEditor.ID;
	}
}