// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.images.handler;

import java.net.URI;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.core.runtime.Status;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.media.ImageFile;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.editor.Page;
import eu.etaxonomy.taxeditor.editor.images.GalleryLabelComposite;
import eu.etaxonomy.taxeditor.editor.images.TaxonImageEditor;
import eu.etaxonomy.taxeditor.store.model.UriDialog;
import eu.etaxonomy.taxeditor.store.operations.CreateImageOperation;

/**
 * @author n.hoffmann
 * @created 27.04.2009
 * @version 1.0
 */
public class CreateImageHandler extends AbstractHandler implements IHandler {
	private static final Logger logger = Logger
			.getLogger(CreateImageHandler.class);

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	public Object execute(ExecutionEvent event) throws ExecutionException {
//		TaxonImageEditor editor = (TaxonImageEditor) EditorUtil.getActiveEditorPage(
//				MultiPageTaxonEditor.PAGE.IMAGE);
		
		MultiPageTaxonEditor editor = (MultiPageTaxonEditor) HandlerUtil.getActiveEditor(event);
		
		TaxonImageEditor page = (TaxonImageEditor) editor.getPage(Page.IMAGE);
		
		Shell shell = HandlerUtil.getActiveShell(event); 
		Taxon taxon = editor.getTaxon();
		
		
		// FIXME right now we have only one description per taxon
		// this will change in the future and then attaching the feature to
		// the firstGroupedComposite will not work anymore
		TaxonDescription description = ((GalleryLabelComposite) page.getFirstGroupedComposite()).getDescription();
		
		
		URI uri = UriDialog.getUri(shell, "Enter image URI", "Enter the new image's URI:");
		// TODO check URI for validity
		
		if (uri == null) {
			return Status.CANCEL_STATUS;
		}
		ImageFile imageFile = ImageFile.NewInstance(uri.toString(), null);
		
		
		
		
		IUndoableOperation operation;
		try {
			operation = new CreateImageOperation(event.getCommand().getName(), 
					editor.getUndoContext(), taxon, description, imageFile, editor);
			EditorUtil.executeOperation(operation);
		} catch (NotDefinedException e) {
			logger.warn("Command name not set");
		}
		
		return null;
	}
}
