/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name;

import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.propertysheet.name.ConceptPropertySource;

/**
 * @author p.ciardelli
 * @created 26.01.2009
 * @version 1.0
 */
public class ConceptComposite extends NameComposite {
	
	private Taxon relatedTaxon;
	private TaxonRelationshipType relationshipType;
	
	/**
	 * 
	 */
	private boolean acceptedTaxonIsFromTaxon;
		
	private ConceptComposite(TaxonNameEditor editor, Composite parent,
			Taxon relatedTaxon, TaxonRelationshipType relationshipType, 
			boolean acceptedTaxonIsFromTaxon) {
		super(editor, parent, NameComposite.CONCEPTRELATION, relatedTaxon);
		
		this.taxon = editor.getTaxon();
		this.relatedTaxon = relatedTaxon;
		this.relationshipType = relationshipType;
		this.setAcceptedTaxonIsFromTaxon(acceptedTaxonIsFromTaxon);
		
		setIsDraggable(true);
		setIcon(CONCEPT_ICON);
		setFont(getViewerFont());
		setIndent(CONCEPT_INDENT);
		
		showRelationshipType();
		showSec();
				
		initTextViewer(relatedTaxon);
	}
	
	private void showRelationshipType() {
		setNonEditableInfo(relationshipType.getLabel());
	}

	private void showSec() {
		if (relatedTaxon == null) {
			return;
		}
		
		if (relatedTaxon.getSec() == null) {
			setNonEditableInfo("sec. ???");
		} else {
			setNonEditableInfo("sec. " + relatedTaxon.getSec().getTitleCache());
		}
	}

	public static ConceptComposite getNewInstance(TaxonNameEditor editor, Composite parent, TaxonRelationship relationship){

		TaxonRelationshipType relationshipType = relationship.getType();
		
		if (relationship.getToTaxon().equals(editor.getTaxon())) {
			return new ConceptComposite (editor, parent, 
					relationship.getFromTaxon(), relationshipType, false);
		} else {
			return new ConceptComposite (editor, parent, 
					relationship.getToTaxon(), relationshipType, true);
		} 
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.GroupedComposite#getViewerFont()
	 */
	@Override
	protected Font getViewerFont() {
		return CONCEPT_FONT;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.IHasPropertySource#getPropertySource()
	 */
	
	public IPropertySource getPropertySource() {
		return new ConceptPropertySource(relatedTaxon);
	}

	public Taxon getRelatedTaxon() {
		return relatedTaxon;
	}
	
	protected TaxonNameBase<?, ?> getName() {
		return relatedTaxon.getName();
	}
	
	protected void calculateErrors() {
		super.calculateErrors();
		
		textViewer.setShowSecError(relatedTaxon);
	}
	
	public Object getData () {
		return getRelatedTaxon();
	}

	/**
	 * @param acceptedTaxonIsFromTaxon the acceptedTaxonIsFromTaxon to set
	 */
	public void setAcceptedTaxonIsFromTaxon(boolean acceptedTaxonIsFromTaxon) {
		this.acceptedTaxonIsFromTaxon = acceptedTaxonIsFromTaxon;
	}

	/**
	 * @return the acceptedTaxonIsFromTaxon
	 */
	public boolean isAcceptedTaxonIsFromTaxon() {
		return acceptedTaxonIsFromTaxon;
	}
}






