/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name;

import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.name.HomotypicalGroup;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.propertysheet.name.MisapplicationPropertySource;
import eu.etaxonomy.taxeditor.store.operations.ChangeConceptToSynonymOperation;

/**
 * @author p.ciardelli
 * @created 13.01.2009
 * @version 1.0
 */
public class MisappliedNameComposite extends NameComposite {
	
	private Taxon misappliedName;
	
	public MisappliedNameComposite(TaxonNameEditor editor, Composite parent, Taxon misappliedName) {
		super(editor, parent, NameComposite.MISAPPLIED_NAME, misappliedName);
		
		this.taxon = editor.getTaxon();
		this.misappliedName = misappliedName;
		
		setIsDraggable(true);
		setIcon(MISAPPLIEDNAME_ICON);
		setFont(getViewerFont());
		setIndent(MISAPPLIEDNAME_INDENT);
		
		showSec();		
		
		initTextViewer(misappliedName);
	}

	private void showSec() {
		if (misappliedName == null) {
			return;
		}
		
		if (misappliedName.getSec() == null) {
			setNonEditableInfo("sec. ???");
		} else {
			setNonEditableInfo("sec. " + misappliedName.getSec().getTitleCache());
		}
	}
	
	public Taxon getMisappliedName() {
		return misappliedName;
	}
		
	public boolean setParent(Composite parent) {

		if (super.setParent(parent)) {	
			
			// If this has been moved to the misapplied names group, do nothing
			if (parent instanceof MisappliedGroupComposite) {
				return true;
			}

			// Has this been moved to a HomotypicalGroup?
			if (parent instanceof HomotypicalGroupComposite) {
				
				HomotypicalGroup homotypicalGroup = 
						((HomotypicalGroupComposite)parent).getGroup();
				
				IUndoableOperation operation = new ChangeConceptToSynonymOperation
						("change misapplication to synonym", editor.getUndoContext(), taxon, misappliedName, homotypicalGroup, editor);
				EditorUtil.executeOperation(operation);
			}
			return true;

		}
		return false;
	}
	
	public IPropertySource getPropertySource() {
		return new MisapplicationPropertySource(misappliedName);
	}

	@Override
	protected Font getViewerFont() {
		return MISAPPLIEDNAME_FONT;
	}
	
	protected void calculateErrors() {
		super.calculateErrors();
		
		textViewer.setShowSecError(misappliedName);
	}

	@Override
	protected TaxonNameBase<?, ?> getName() {
		return misappliedName.getName();
	}
	
	public Object getData () {
		return getMisappliedName();
	}
}