// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name.handler;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.editor.Page;
import eu.etaxonomy.taxeditor.editor.name.TaxonNameEditor;
import eu.etaxonomy.taxeditor.propertysheet.name.SynonymPropertySource;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.operations.SwapSynonymAndAcceptedOperation;

/**
 * @author n.hoffmann
 * @created 21.04.2009
 * @version 1.0
 */
public class SwapSynonymAndAcceptedHandler extends AbstractHandler implements
		IHandler {
	private static final Logger logger = Logger
			.getLogger(SwapSynonymAndAcceptedHandler.class);

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	public Object execute(ExecutionEvent event) throws ExecutionException {
		MultiPageTaxonEditor multiEditor = EditorUtil.getActiveEditor();
		
		if (multiEditor.isDirty()) {
			if (!MessageDialog.openConfirm((Shell) multiEditor.getAdapter(Shell.class), "Save before proceeding", 
					"All changes must be saved before proceeding.\n\n" +
					"Save current changes?")) {
				return null;
			}
			multiEditor.doSave(null);
		}
		
		TaxonNameEditor editor = (TaxonNameEditor) multiEditor.getPage(Page.NAME);
		
		ISelection menuSelection = HandlerUtil.getActiveMenuSelection(event);
		Synonym synonym = (Synonym) ((SynonymPropertySource) ((StructuredSelection) menuSelection).getFirstElement()).getTaxonBase();
		
		
		SwapSynonymAndAcceptedOperation operation;
		
		try {
			operation = new SwapSynonymAndAcceptedOperation(event.getCommand().getName(), editor.getUndoContext(),
								editor.getTaxon(), synonym, editor);
			EditorUtil.executeOperation(operation);
			
			// TODO this is all very spooky
			// After performing the logic we do have to mangle around with the windows			
			Taxon newTaxon = operation.getNewTaxon();
			
			// save and delete the taxon data
			CdmStore.getTaxonService().save(newTaxon);
			CdmStore.getTaxonService().delete(editor.getTaxon());
			
			multiEditor.doSave(null);
			EditorUtil.close(multiEditor);
			
			// open an editor with the new 
			EditorUtil.open(newTaxon.getUuid());
			
		} catch (NotDefinedException e) {
			logger.warn("Command name not set");
		} catch (PartInitException e) {
			logger.error("Could not open editor with new taxon", e);
		}

		return null;
	}
}
