/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.description;

import java.util.Vector;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.PropertyDescriptor;

import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.taxeditor.propertysheet.ICdmBasePropertySource;

/**
 * @author p.ciardelli
 * @created 29.08.2008
 * @version 1.0
 */
public class TaxonDescriptionPropertySource implements ICdmBasePropertySource {
	
	// The TaxonDescription whose properties are being displayed	
	private TaxonDescription taxonDescription;
	
	// If this is a property with a parent, the parent's property ID
	private String parentid;
	
    // Property unique keys
	public static final String P_ID_LABEL = "label";
	public static final String P_ID_UUID = "uuid";

    // Property display keys
	public String P_LABEL = "Description Label";
	public static final String P_UUID = "UUID";		
	
	protected static final String[] TOP_LEVEL_PROPERTIES = new String[] {
		P_ID_LABEL};		
		
	/**
	 * Constructor for top level property fields. All fields that are not subfields
	 *  should be listed here.
	 * @param name
	 */
	public TaxonDescriptionPropertySource(TaxonDescription taxonDescription) {
		this(taxonDescription, null, TOP_LEVEL_PROPERTIES);
	}
	
	public TaxonDescriptionPropertySource(TaxonDescription taxonDescription, String parentid, 
			String[] keys) {
		
		if (taxonDescription.isImageGallery()) {
			P_LABEL = "Image Gallery Label";
		}
		
		this.taxonDescription = taxonDescription;
		this.setParentid(parentid);
		for (String key : keys) {
			addDescriptor(key);
		}
	}

	protected Vector<PropertyDescriptor> descriptors = new Vector<PropertyDescriptor>();
	/**
	 * Add descriptor for a given property.
	 * 
	 * Notes on Descriptor:
	 * 
	 *  PropertyDescriptor - uneditable cell value
	 *  ComboBoxPropertyDescriptor - dropdown list, property supplied must be integer-based
	 *  TextPropertyDescriptor - editable cell value
	 *  
	 *  If any descriptor calls setCategory, all descriptors w/out a category are put in 
	 *  category "Misc".
	 *  
	 *  descriptor.setFilterFlags (new String[] { IPropertySheetEntry.FILTER_ID_EXPERT }) -
	 *   this descriptor shown under advanced properties
	 *  
	 * @param id
	 */
	protected void addDescriptor(String id) {
		if (id.equals(P_ID_LABEL)) {
			descriptors.addElement(
					new PropertyDescriptor(P_ID_LABEL, P_LABEL));
		}
		if (id.equals(P_ID_UUID)) {
			descriptors.addElement(
					new PropertyDescriptor(P_ID_UUID, P_UUID));
		}
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
	 */
	public Object getEditableValue() {
		return this;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
	 */
	public IPropertyDescriptor[] getPropertyDescriptors() {
		return (IPropertyDescriptor[]) descriptors.toArray(
                new IPropertyDescriptor[descriptors.size()]);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
	 */
	public Object getPropertyValue(Object id) {
		if (id.equals(P_ID_LABEL)) {
			return taxonDescription.getTitleCache();
		}
        if (id.equals(P_ID_UUID)) {
			return taxonDescription.getUuid().toString();
        }
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
	 */
	public boolean isPropertySet(Object id) {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
	 */
	public void resetPropertyValue(Object id) {}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
	 */
	public void setPropertyValue(Object id, Object value) {
		if (id.equals(P_ID_LABEL)) {
			taxonDescription.setTitleCache((String) value);
		}
	}

	/**
	 * @param parentid the parentid to set
	 */
	public void setParentid(String parentid) {
		this.parentid = parentid;
	}

	/**
	 * @return the parentid
	 */
	public String getParentid() {
		return parentid;
	}
}
