// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.images;

import java.util.Vector;

import org.apache.log4j.Logger;
import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.PropertyDescriptor;

import eu.etaxonomy.cdm.model.media.ImageFile;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.propertysheet.ICdmBasePropertySource;

/**
 * @author p.ciardelli
 * @created 30.03.2009
 * @version 1.0
 */
public class ImagePropertySource implements ICdmBasePropertySource {
	private static final Logger logger = Logger
			.getLogger(ImagePropertySource.class);
	
	private ImageFile imageFile;

	private Taxon taxon;

    // Property unique keys
	public static final String P_ID_IMAGE = "image";

    // Property display keys
	public static final String P_IMAGE = "Image URI";
	
	/**
	 * @param url
	 */
	public ImagePropertySource(Taxon taxon, ImageFile imageFile) {
		this.setTaxon(taxon);
		this.imageFile = imageFile;
		
		addDescriptor(P_ID_IMAGE);
	}

	protected Vector<PropertyDescriptor> descriptors = new Vector<PropertyDescriptor>();
	
	protected void addDescriptor(String id) {
		if (id.equals(P_ID_IMAGE)) {
			descriptors.addElement(
					new PropertyDescriptor(P_ID_IMAGE, P_IMAGE));
		}
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
	 */
	public Object getEditableValue() {
		return this;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
	 */
	public IPropertyDescriptor[] getPropertyDescriptors() {
		return (IPropertyDescriptor[]) descriptors.toArray(
                new IPropertyDescriptor[descriptors.size()]);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
	 */
	public Object getPropertyValue(Object id) {
        if (id.equals(P_ID_IMAGE)) {
			return imageFile.getUri();
        }
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
	 */
	public boolean isPropertySet(Object id) {
		return false;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
	 */
	public void resetPropertyValue(Object id) {}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
	 */
	public void setPropertyValue(Object id, Object value) {
		
		logger.error("Not yet implemented.");
		
//		if (id.equals(P_ID_IMAGE)) {
//			
//			// TODO put this in an operation to allow undo
//			ImageFile imageFile = ImageFile.NewInstance((String) value, null);
//			
//			ImagesUtil.removeTaxonImage(taxon, imageFile);
//			ImagesUtil.addTaxonImage(taxon, imageFile);
//			
//			this.imageFile = imageFile;
//			
//		}
	}
	
	public ImageFile getImageFile(){
		return imageFile;
	}

	/**
	 * @param taxon the taxon to set
	 */
	public void setTaxon(Taxon taxon) {
		this.taxon = taxon;
	}

	/**
	 * @return the taxon
	 */
	public Taxon getTaxon() {
		return taxon;
	}
}
