/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.namerelations.wizard;

import java.util.HashSet;
import java.util.Set;

import org.eclipse.core.databinding.observable.list.WritableList;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.model.name.NameRelationship;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.propertysheet.namerelations.wizard.ChooseRelationWizardPage.TemporaryNameRelationship;

/**
 * @author p.ciardelli
 * @created 06.06.2008
 * @version 1.0
 */
public class NameRelationsListWizard extends Wizard {
	
	private TaxonNameBase<?, ?> name;

	private WritableList nameRelationsTemp;

	public NameRelationsListWizard(TaxonNameBase<?, ?> name) {
		super();
		
		this.name = name;
		
		initNameRelationsList();
	}

	/**
	 * 
	 */
	private void initNameRelationsList() {
		nameRelationsTemp = new WritableList();
		nameRelationsTemp.addAll(name.getNameRelations());
	}

	public void addPages() {
		IWizardPage chooseNamePage = new ListNameRelationsWizardPage(name, nameRelationsTemp);
    	addPage(chooseNamePage);
    }
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
				
		Set<NameRelationship> nameRelations = name.getNameRelations();
		Set<NameRelationship> removeRelations = new HashSet<NameRelationship>();
		
		for (NameRelationship relation : nameRelations) {
			
			// Remove any relations no longer in temporary list
			if (!nameRelationsTemp.contains(relation)) {
				removeRelations.add(relation);
			} else {
			
				// Replace temporary relationship w real one
				if (relation instanceof TemporaryNameRelationship) {
					removeRelations.add(relation);
					if (name.equals(relation.getFromName())) {
						name.addRelationshipToName(relation.getToName(), 
								relation.getType(), 
								relation.getRuleConsidered());
					} else {
						name.addRelationshipFromName(relation.getFromName(), 
								relation.getType(), 
								relation.getRuleConsidered());
					}
				}
			}
		}
		for (NameRelationship relation : removeRelations) {
			name.removeNameRelationship(relation);
		}

		return true;
	}
	
    /* (non-Javadoc)
     * @see org.eclipse.jface.wizard.Wizard#performCancel()
     */
    public boolean performCancel() {
    	// Remove all temporary relationships
		Set<NameRelationship> nameRelations = name.getNameRelations();
		Set<NameRelationship> removeRelations = new HashSet<NameRelationship>();
		
		for (NameRelationship relation : nameRelations) {
			if (relation instanceof TemporaryNameRelationship) {
				removeRelations.add(relation);
			}
		}
		for (NameRelationship relation : removeRelations) {
			name.removeNameRelationship(relation);
		}
        return true;
    }
}