/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */
package eu.etaxonomy.taxeditor.propertysheet.type;

import java.util.Collection;

import org.apache.log4j.Logger;
import org.eclipse.ui.views.properties.PropertyDescriptor;
import org.eclipse.ui.views.properties.TextPropertyDescriptor;

import eu.etaxonomy.cdm.model.name.NameTypeDesignation;
import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.name.TypeDesignationBase;
import eu.etaxonomy.cdm.model.name.TypeDesignationStatusBase;
import eu.etaxonomy.taxeditor.propertysheet.CollectionPropertySource;

public class TypeCollectionPropertySource extends CollectionPropertySource {
	private static final Logger logger = Logger
			.getLogger(TypeCollectionPropertySource.class);
	
	private TaxonNameBase<?, ?> name;

	public TypeCollectionPropertySource(TaxonNameBase<?, ?> name, Collection<?> collection) {
		super(collection);
		this.setName(name);
	}
	
	protected void addDescriptor(Object item) {
		String itemDisplayName = getItemDisplayName(item);
		
		if (item instanceof NameTypeDesignation) {
			descriptors.addElement(
					new PropertyDescriptor(item, itemDisplayName));
		}
		
		if (item instanceof SpecimenTypeDesignation) {
			descriptors.addElement(
					new TextPropertyDescriptor(item, itemDisplayName));
		}
	}
	
	@Override
	protected String getItemDisplayName(Object item) {
		String str = "UNDEFINED";

		if (item instanceof SpecimenTypeDesignation) {
			
			TypeDesignationStatusBase<?> status = ((TypeDesignationBase<?>) item).getTypeStatus();
			
			if (status != null) {
				str = status.getLabel();
			}
		}

		if (item instanceof NameTypeDesignation) {
			
			NameTypeDesignation typeDesignation = (NameTypeDesignation) item;
			
			if (typeDesignation.isLectoType()) {
				str = "Lectotype";
			} else {
				str = "Type";
			}
		}
		
		return str;
	}

	@Override
	public Object getPropertyValue(Object id) {
		
		if (id instanceof TypeDesignationBase) {
			return new TypeDesignationPropertySource((TypeDesignationBase<?>) id);
		}
		return null;
	}	
	
	@Override
	public void setPropertyValue(Object id, Object value) {
				
		if (id instanceof SpecimenTypeDesignation && value instanceof String) {
			SpecimenTypeDesignation typeDesignation = (SpecimenTypeDesignation) id;
			
			if (typeDesignation.getTypeSpecimen() != null) {
				typeDesignation.getTypeSpecimen().setTitleCache((String) value);
			} else {
				logger.warn("'typeDesignation.getTypeSpecimen()' returned null.");
			}
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.propertysheet.CollectionPropertySource#toString()
	 */
	@Override
	public String toString() {
		return "";
	}

	/**
	 * @param name the name to set
	 */
	public void setName(TaxonNameBase<?, ?> name) {
		this.name = name;
	}

	/**
	 * @return the name
	 */
	public TaxonNameBase<?, ?> getName() {
		return name;
	}
}