/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.type.wizard;

import org.eclipse.core.databinding.beans.BeansObservables;
import org.eclipse.core.databinding.observable.list.WritableList;
import org.eclipse.core.databinding.observable.map.IObservableMap;
import org.eclipse.jface.databinding.viewers.ObservableListContentProvider;
import org.eclipse.jface.databinding.viewers.ObservableMapLabelProvider;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;

import eu.etaxonomy.cdm.model.name.NameTypeDesignation;
import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.name.TypeDesignationBase;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.store.model.NameUtil;

/**
 * @author p.ciardelli
 * @created 11.02.2009
 * @version 1.0
 */
public class ListTypeWizardPage extends WizardPage {
	
	private TaxonNameBase<?, ?> name;

	/**
	 * @param name
	 */
	public ListTypeWizardPage(TaxonNameBase<?, ?> name, WritableList typeDesignationsList) {
		super("");
		this.name = name;
		
		this.typeDesignationsList = typeDesignationsList;

		setTitle("Type designations for \""
				+ NameUtil.getDisplayName(name) + "\".");
		setDescription("Select a type designation and click \"Edit ...\" or \"Remove\", or click \"Add ...\" to create a new designation.");
	}
	
	private Table typeDesignationsTable;
	private WritableList typeDesignationsList = new WritableList();

	private Button btnRemove;
	private Button btnEdit;

	private TypeDesignationBase<?> typeDesignation;
	private TableViewer tableViewer;


	public void createControl(Composite parent) {
		Composite container = new Composite(parent, SWT.NULL);
		final GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 3;
		container.setLayout(gridLayout);

		setControl(container);

		btnEdit = new Button(container, SWT.NONE);
		btnEdit.setText("Edit ...");
		btnEdit.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if (getSelectedTypeDesignation() != null) {	
					createTypeDesignationWizard(getSelectedTypeDesignation());
				}
			}
		});

		btnRemove = new Button(container, SWT.NONE);
		btnRemove.setText("Remove");
		btnRemove.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				if (getSelectedTypeDesignation() != null) {
					typeDesignationsList.remove(getSelectedTypeDesignation());
					setSelectedTypeDesignation(null);
				}
			}
		});

		setEnableTypeDesignationButtons(false);

		final Button btnAdd = new Button(container, SWT.NONE);
		final GridData gd_btnAdd = new GridData(SWT.RIGHT, SWT.CENTER, true,
				false);
		btnAdd.setLayoutData(gd_btnAdd);
		btnAdd.setText("Add ...");
		btnAdd.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				createTypeDesignationWizard(null);
			}
		});

		tableViewer = new TableViewer(container, SWT.BORDER | SWT.SINGLE);

		typeDesignationsTable = tableViewer.getTable();
		typeDesignationsTable.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true,
				true, 3, 1));
		typeDesignationsTable.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) { 
				setEnableTypeDesignationButtons(true);
				if (e.item.getData() instanceof TypeDesignationBase) {
					setSelectedTypeDesignation((TypeDesignationBase<?>) e.item.getData());
				}
			}
		});

		ObservableListContentProvider providerList = new ObservableListContentProvider();
		tableViewer.setContentProvider(providerList);

//		IObservableMap[] providerMaps = BeansObservables.observeMaps(
//				providerList.getKnownElements(), SpecimenTypeDesignation.class,
//				new String[] { "typeSpecimen", "typeStatus" });
		IObservableMap[] providerMaps = BeansObservables.observeMaps(
				providerList.getKnownElements(), TypeDesignationBase.class,
				new String[] {  });		
		tableViewer.setLabelProvider(new ObservableMapLabelProvider(
				providerMaps) {
			public String getColumnText(Object element, int columnIndex) {
				if (element instanceof TypeDesignationBase) {
					return getTypeDesignationString((TypeDesignationBase<?>) element);
				}
				return "";
			}

			public Image getColumnImage(Object element, int columnIndex) {
				if (element instanceof TypeDesignationBase) {
					return getTypeDesignationImage((TypeDesignationBase<?>) element);
				}
				return null;
			}
		});
		
		tableViewer.setInput(typeDesignationsList);
		tableViewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				if (((StructuredSelection) event.getSelection())
						.getFirstElement() instanceof TypeDesignationBase) {
					TypeDesignationBase<?> typeDesignation = (TypeDesignationBase<?>) 
							((StructuredSelection) event.getSelection()).getFirstElement();
					createTypeDesignationWizard(typeDesignation);
				}
			}
		});
	}

	private void setSelectedTypeDesignation(TypeDesignationBase<?> typeDesignation) {
		this.typeDesignation = typeDesignation;
	}

	private TypeDesignationBase<?> getSelectedTypeDesignation() {
		return typeDesignation;
	}
	
	private void createTypeDesignationWizard(TypeDesignationBase<?> typeDesignation) {
		Wizard wizard = new TypeDesignationWizard(typeDesignation, name, typeDesignationsList);
		
		WizardDialog dialog = new WizardDialog(EditorUtil.getShell(), wizard);
		dialog.create();
		dialog.open();
//		if (dialog.open() == Window.OK) ...
	}

	protected void setEnableTypeDesignationButtons(boolean enabled) {
		btnRemove.setEnabled(enabled);
		btnEdit.setEnabled(enabled);
	}

	private Image getTypeDesignationImage(TypeDesignationBase<?> typeDesignation) {
		return null;
	}

	private String getTypeDesignationString(TypeDesignationBase<?> typeDesignation) {
		String str = "";
		if (typeDesignation instanceof SpecimenTypeDesignation) {
			if (((SpecimenTypeDesignation) typeDesignation).getTypeSpecimen() != null) {
				str += ((SpecimenTypeDesignation) typeDesignation).getTypeSpecimen().getTitleCache();
			} else {
				str += "UNDEFINED";
			}
			if (typeDesignation.getTypeStatus() != null) {
				str += " [" + typeDesignation.getTypeStatus().getLabel() + "]";
			}
		}
		
		if (typeDesignation instanceof NameTypeDesignation) {
			if (((NameTypeDesignation) typeDesignation).getTypeName() != null) {
				str = ((NameTypeDesignation) typeDesignation).getTypeName().getTitleCache();
			}
			
			if (((NameTypeDesignation) typeDesignation).isLectoType()) {
				str += " (Lectotype)";
			}
		}
		
		return str;
	}
}
