/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.handler;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.Dialog;
import org.eclipse.swt.widgets.Shell;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.name.TaxonSearchDialog;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.store.operations.MoveTaxonOperation;

/**
 * @author n.hoffmann
 * @created 01.04.2009
 * @version 1.0
 */
public class MoveTaxonHandler extends AbstractHandler {
	private static final Logger logger = Logger
			.getLogger(MoveTaxonHandler.class);

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	public Object execute(ExecutionEvent event) throws ExecutionException {
		Shell shell = NavigationUtil.getShell();
		Taxon taxon = (Taxon) NavigationUtil.getCurrentSelection(event);
		
		Dialog dialog = new TaxonSearchDialog(shell);
        Object value = ((TaxonSearchDialog) dialog).open();
        
        logger.warn("child " +taxon.toString());
        logger.warn("parent " + ((Taxon) value).toString());
        
		if (value instanceof Taxon) {
			Taxon parentTaxon = (Taxon) value;
			
			if(NavigationUtil.isDirty(parentTaxon)){
				MessageDialog.openWarning(shell, "Unsaved Parent Taxon", "There are unsaved " +
						"changes in the parent taxon. Pleas save first.");
				return null;
			}
			
			IUndoableOperation operation = new MoveTaxonOperation
					("Move taxon to new parent", NavigationUtil.getUndoContext(), 
								taxon, parentTaxon); //$NON-NLS-1$
			NavigationUtil.executeOperation(operation);
		} else {
			logger.warn("TaxonSearchDialog did not return a Taxon object.");
		}
		
		return null;
	}
}
