/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.handler;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.store.internal.TaxeditorStorePlugin;
import eu.etaxonomy.taxeditor.store.operations.CreateChildTaxonOperation;
import eu.etaxonomy.taxeditor.store.operations.IPostOperationEnabled;
import eu.etaxonomy.taxeditor.store.parser.CdmParserUtil;

/**
 * @author n.hoffmann
 * @created 24.03.2009
 * @version 1.0
 */
public class QuickCreateChildTaxonHandler extends AbstractHandler implements
		IHandler {
	private static final Logger logger = Logger
			.getLogger(QuickCreateChildTaxonHandler.class);

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	public Object execute(ExecutionEvent event) throws ExecutionException {
		IPostOperationEnabled postOperationEnabled = HandlerUtil.getActivePart(event) instanceof IPostOperationEnabled ? (IPostOperationEnabled) HandlerUtil.getActivePart(event) : null;

		Shell shell = HandlerUtil.getActiveShell(event);
		Taxon parentTaxon = NavigationUtil.getCurrentSelection(event);
		
		if(NavigationUtil.isDirty(parentTaxon)){
			MessageDialog.openWarning(shell, "Unsaved Parent Taxon", "There are unsaved " +
					"changes in the parent taxon. Pleas save first.");
			return null;
		}
		
		InputDialog dialog = new InputDialog(shell, "Quick create child taxon", 
				"Enter child taxon's name to create a new taxon", null, null);
		if (dialog.open() == Window.OK) {
			
			//TaxonUtil.addChildTaxonBaseIsolated(parentTaxon.getUuid(), dialog.getValue());

			TaxonNameBase name = CdmParserUtil.parseFullReference(dialog.getValue(), null, null);
			
			CreateChildTaxonOperation operation;
			try {
				operation = new CreateChildTaxonOperation(event.getCommand().getName(), 
						NavigationUtil.getUndoContext(), parentTaxon, name, postOperationEnabled);
				IStatus status = EditorUtil.executeOperation(operation);
				if(status.getCode() == TaxeditorStorePlugin.ERROR_SAVING_ZERO_NAME){
					MessageDialog.openWarning(shell, "No Name Specified", "An attempt was made to save a taxon with" +
							" an empty name. Operation was cancelled");
				}
				
				NavigationUtil.selectInNavigator(operation.getChildTaxon(), parentTaxon);
				
			} catch (NotDefinedException e) {
				logger.warn("Command name not set");
			}
			
			
			logger.info("Taxon created");
			
		}
		
		return null;
	}
}
