// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.navigator;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredViewer;
import org.eclipse.jface.viewers.TreeSelection;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.navigator.CommonActionProvider;
import org.eclipse.ui.navigator.ICommonActionConstants;
import org.eclipse.ui.navigator.ICommonActionExtensionSite;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;

/**
 * @author p.ciardelli
 * @created 04.06.2009
 * @version 1.0
 */
public class OpenTaxonActionProvider extends CommonActionProvider {
	private static final Logger logger = Logger
			.getLogger(OpenTaxonActionProvider.class);

	OpenTaxonAction openTaxonAction;

	/* (non-Javadoc)
	 * @see org.eclipse.ui.navigator.CommonActionProvider#init(org.eclipse.ui.navigator.ICommonActionExtensionSite)
	 */
	public void init(ICommonActionExtensionSite aSite) {
		super.init(aSite);
		openTaxonAction = new OpenTaxonAction(aSite.getStructuredViewer()); 
        
	}

    /* (non-Javadoc)
     * @see org.eclipse.ui.actions.ActionGroup#fillActionBars(org.eclipse.ui.IActionBars)
     */
    public void fillActionBars(IActionBars actionBars) {
        super.fillActionBars(actionBars);
        // forward doubleClick to doubleClickAction
        actionBars.setGlobalActionHandler(ICommonActionConstants.OPEN,
              openTaxonAction);
    }
    
    class OpenTaxonAction extends Action {

    	private StructuredViewer structuredViewer;

		/**
		 * @param structuredViewer
		 */
		public OpenTaxonAction(StructuredViewer structuredViewer) {
			this.structuredViewer = structuredViewer;
		}

		/* (non-Javadoc)
    	 * @see org.eclipse.jface.action.Action#run()
    	 */
    	public void run() {
			ISelection selection = structuredViewer.getSelection();
			if (selection instanceof TreeSelection) {
				Object[] selections = ((TreeSelection) selection).toArray();
				for (Object element : ((TreeSelection) selection).toArray()) {
					if (element instanceof Taxon) {
						NavigationUtil.openEditor((Taxon) element);
					}					
				}
			}
		}    	
    }
}
