// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.navigator;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.util.LocalSelectionTransfer;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.TreeSelection;
import org.eclipse.swt.dnd.DropTargetEvent;
import org.eclipse.swt.dnd.TransferData;
import org.eclipse.ui.navigator.CommonDropAdapter;
import org.eclipse.ui.navigator.CommonDropAdapterAssistant;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.store.model.NameUtil;
import eu.etaxonomy.taxeditor.store.model.TaxonUtil;
import eu.etaxonomy.taxeditor.store.operations.MoveTaxonOperation;

/**
 * @author p.ciardelli
 * @created 03.06.2009
 * @version 1.0
 */
public class TaxonDropAdapterAssistant extends CommonDropAdapterAssistant {
	private static final Logger logger = Logger
			.getLogger(TaxonDropAdapterAssistant.class);

	public static final String ID = "eu.etaxonomy.taxeditor.navigation.navigator.dropassistant"; //$NON-NLS-1$
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.navigator.CommonDropAdapterAssistant#handleDrop(org.eclipse.ui.navigator.CommonDropAdapter, org.eclipse.swt.dnd.DropTargetEvent, java.lang.Object)
	 */
	@Override
	public IStatus handleDrop(CommonDropAdapter dropAdapter,
			DropTargetEvent dropTargetEvent, Object target) {
		
		ISelection selection = LocalSelectionTransfer.getTransfer().getSelection();
		if (selection instanceof TreeSelection) {
			Object element = ((TreeSelection) selection).getFirstElement();
			if (element instanceof Taxon) {
				Taxon childTaxon = (Taxon) element;
				if (target instanceof Taxon) {
					Taxon parentTaxon = (Taxon) target;
					
					return moveTaxon(childTaxon, parentTaxon);
				}
			}
		}
		
//		IContainer target = getActualTarget((IResource) dropAdapter
//				.getCurrentTarget());
//		IContainer target = 
//		if (target != null && target.isAccessible()) {
//			try {
//				target.refreshLocal(IResource.DEPTH_ONE, null);
//			} catch (CoreException e) {
//			}
//		}
		
		return Status.CANCEL_STATUS;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.navigator.CommonDropAdapterAssistant#validateDrop(java.lang.Object, int, org.eclipse.swt.dnd.TransferData)
	 */
	@Override
	public IStatus validateDrop(Object target, int operation,
			TransferData transferType) {
		if (target instanceof Taxon) {
			return Status.OK_STATUS;
		}
		return Status.CANCEL_STATUS;
	}
	

	/**
	 * @param childTaxon
	 * @param parentTaxon
	 * @return
	 */
	private IStatus moveTaxon(Taxon childTaxon, Taxon newParentTaxon) {
		
		// Make sure parentTaxon is not a child
		if (TaxonUtil.isTaxonChildOfTaxon(newParentTaxon, childTaxon)) {
			
			MessageDialog.openError(NavigationUtil.getShell(), "Can't move taxon.",
					"'" + NameUtil.getDisplayName(childTaxon) + "' sits above " +
					"'" + NameUtil.getDisplayName(newParentTaxon) + "' " +
					"in the taxonomic hierarchy.");
			
			return Status.CANCEL_STATUS;
		}
		
		// Make sure taxon is not being dropped onto itself
		if (childTaxon.equals(newParentTaxon)) {
			return Status.CANCEL_STATUS;
		}
		
		// Make sure parent taxon does not have unsaved changes
		if (NavigationUtil.isDirty(newParentTaxon)){
			MessageDialog.openWarning(NavigationUtil.getShell(), "Unsaved Parent Taxon", "There are unsaved " +
			"changes in the parent taxon. Pleas save first.");
			return Status.CANCEL_STATUS;
		}
		
		IUndoContext workspaceUndoContext = NavigationUtil.getWorkbenchUndoContext();
		if (workspaceUndoContext == null) {
			logger.error("Workspace undo context is null. DND operation cancelled");
			return Status.CANCEL_STATUS;
		}
		IUndoableOperation operation = new MoveTaxonOperation
				("Move Taxon", workspaceUndoContext, childTaxon, newParentTaxon);
		NavigationUtil.executeOperation(operation);	
		
		logger.info("Moved taxon " + childTaxon + " to new parent " + newParentTaxon);
		
		NavigationUtil.selectInNavigator(childTaxon, newParentTaxon);
		
		return Status.OK_STATUS;
	}
}
