// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.navigator;

import org.apache.log4j.Logger;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.navigator.ILinkHelper;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.TaxonEditorInput;

/**
 * When a taxon is open in an editor and this editor has focus, its entry in the
 * navigator's taxonomic tree is selected.
 * 
 * @author p.ciardelli
 * @created 03.06.2009
 * @version 1.0
 */
public class TaxonLinkHelper implements ILinkHelper {
	private static final Logger logger = Logger
			.getLogger(TaxonLinkHelper.class);

	public static final String ID = "eu.etaxonomy.taxeditor.navigation.taxonlinkhelper"; //$NON-NLS-1$
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.navigator.ILinkHelper#activateEditor(org.eclipse.ui.IWorkbenchPage, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	public void activateEditor(IWorkbenchPage page,
			IStructuredSelection selection) {
		if (selection == null || selection.isEmpty()) {
			return;
		}
		if (selection.getFirstElement() instanceof Taxon) {
			Taxon taxon = (Taxon) selection.getFirstElement();
			TaxonEditorInput taxonEditorInput = TaxonEditorInput.NewInstance(taxon.getUuid());
			IEditorPart editor = null;
			if ((editor = page.findEditor(taxonEditorInput)) != null) {
				page.bringToTop(editor);
			}
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.navigator.ILinkHelper#findSelection(org.eclipse.ui.IEditorInput)
	 */
	public IStructuredSelection findSelection(IEditorInput editorInput) {
		if (editorInput instanceof TaxonEditorInput) {
			Taxon taxon = ((TaxonEditorInput) editorInput).getTaxon();
			if (taxon != null) {
				return new StructuredSelection(taxon);
			}
		}
		return StructuredSelection.EMPTY;
	}
}
