// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.datasource.wizard;

import org.apache.log4j.Logger;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.database.CdmDataSource;
import eu.etaxonomy.cdm.database.ICdmDataSource;

/**
 * @author n.hoffmann
 * @created 19.05.2009
 * @version 1.0
 */
public class CdmDataSourceMySQLWizardPage extends CdmDataSourceCredentialsWizardPage {


	private static final Logger logger = Logger
			.getLogger(CdmDataSourceMySQLWizardPage.class);
	
	private Text portText;
	private Text serverText;

	/**
	 * @param pageName
	 */
	protected CdmDataSourceMySQLWizardPage(ICdmDataSource dataSource) {
		super("MySQL");
		setTitle("Enter credentials for MySQL database");
		this.dataSource = dataSource;
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.store.datasource.CdmDataSourceCredentialsWizardPage#createDatabaseForm()
	 */
	@Override
	public void createDatabaseForm() {
		logger.warn("Creating");
		
		// Create group composite for location data 
		locationGroup = new Group(composite, SWT.NONE);
		locationGroup.setText("Location");
		locationGroup.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 2, 1));
		GridLayout locationLayout = new GridLayout();
		locationLayout.numColumns = 2;
		locationGroup.setLayout(locationLayout);

		// Create host label
		Label serverLabel = new Label(locationGroup, SWT.NONE);
		serverLabel.setText("Host:");

		// Create host input
		serverText = new Text(locationGroup, SWT.BORDER);
		serverText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		serverText.addKeyListener(this);

		// Create port label
		Label portLabel = new Label(locationGroup, SWT.NONE);
		portLabel.setText("Port:");

		// Create port input
		portText = new Text(locationGroup, SWT.BORDER);
		portText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		portText.addKeyListener(this);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.store.datasource.CdmDataSourceCredentialsWizardPage#testDbConfiguration()
	 */
	@Override
	public void testDbConfiguration() {
		ICdmDataSource dataSource = CdmDataSource.NewMySqlInstance(
				getWizard().getServer(), 
				getWizard().getDatabase(), 
				getWizard().getPort(), 
				getWizard().getUsername(), 
				getWizard().getPassword()
		);
		if (dataSource.testConnection()) {
			MessageDialog.openConfirm(parent.getShell(), "Test successful", "Test successful");
		} else {
			MessageDialog.openWarning(parent.getShell(), "Test unsuccessful", "Test unsuccessful");
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.store.datasource.CdmDataSourceCredentialsWizardPage#updateLocation()
	 */
	@Override
	public void updateLocation() {
		getWizard().setServer(serverText.getText());
		int port = new Integer(portText.getText());
		getWizard().setPort(port);
	}
}
