// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.model;

import org.eclipse.jface.resource.ColorRegistry;
import org.eclipse.jface.resource.FontRegistry;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IEditorReference;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.themes.ITheme;
import org.eclipse.ui.themes.IThemeManager;

import eu.etaxonomy.taxeditor.store.internal.TaxeditorStorePlugin;

/**
 * @author n.hoffmann
 * @created 11.05.2009
 * @version 1.0
 */
public abstract class AbstractUtility {
	
	/**
	 * @return
	 */
	public static Shell getShell() {
		return TaxeditorStorePlugin.getDefault().getWorkbench()
				.getActiveWorkbenchWindow().getShell();
	}
	
	public static IWorkbenchPage getActivePage(){
		return TaxeditorStorePlugin.getDefault().getWorkbench()
			.getActiveWorkbenchWindow().getActivePage();
	}
	
	public static boolean closeAll() {
		for (IEditorReference reference : getActivePage().getEditorReferences()) {
			if (!getActivePage().closeEditor(reference.getEditor(false), true)) {
				return false;
			}
		}
		return true;
	}

	public static ITheme getCurrentTheme(){
		IThemeManager themeManager = TaxeditorStorePlugin.getDefault().getWorkbench().getThemeManager();
		return themeManager.getCurrentTheme();
	}
	
	/**
	 * Fonts registered to the plugin may be obtained with the Eclipse themeing functionality.
	 * Thus fonts are chooseable by the user via Preferences->General->Appearance->Colors and Fonts
	 * 
	 * @return the FontRegistry for the current theme
	 */
	public static FontRegistry getFontRegistry(){
		return getCurrentTheme().getFontRegistry();
	}
	
	/**
	 * Color registered to the plugin may be obtained with the Eclipse themeing functionality.
	 * Thus colors are editable by the user via Preferences->General->Appearance->Colors and Fonts
	 * 
	 * @return the ColorRegistry for the current theme
	 */
	public static ColorRegistry getColorRegistry(){
		return getCurrentTheme().getColorRegistry();
	}
	
}
