// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.model;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.description.TextData;
import eu.etaxonomy.cdm.model.media.ImageFile;
import eu.etaxonomy.cdm.model.media.Media;
import eu.etaxonomy.cdm.model.media.MediaRepresentation;
import eu.etaxonomy.cdm.model.media.MediaRepresentationPart;
import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * @author p.ciardelli
 * @created 31.03.2009
 * @version 1.0
 */
public class ImagesUtil {
	
	public static Set<ImageFile> getImages(TaxonDescription description){
		Set<ImageFile> images = new HashSet<ImageFile>();
		
		for (DescriptionElementBase element : description.getElements()){
			
			Feature feature = element.getFeature();
			
			if(feature.equals(Feature.IMAGE())){
				Set<Media> medias = element.getMedia();
				
				for(Media media : medias){
					Set<MediaRepresentation> representations = media.getRepresentations();
					
					for(MediaRepresentation representation : representations){
						List<MediaRepresentationPart> parts = representation.getParts();
						
						for (MediaRepresentationPart part : parts){
							if(part instanceof ImageFile){
								images.add((ImageFile) part);
							}
						}
					}							
				}										
			}
		}
		
		return images;
	}

	/**
	 * @param taxon
	 * @param imageFile
	 */
	public static void addTaxonImage(Taxon taxon, DescriptionBase<?> imageGallery, ImageFile imageFile) {
		
		DescriptionElementBase descriptionElement = TextData.NewInstance(Feature.IMAGE());
		
		Media media = Media.NewInstance();
		MediaRepresentation representation = MediaRepresentation.NewInstance();
		
		representation.addRepresentationPart(imageFile);
		
		media.addRepresentation(representation);
		
		descriptionElement.addMedia(media);
		
		imageGallery.addElement(descriptionElement);
		
	}

	/**
	 * @param taxon
	 * @param imageFile
	 */
	public static void removeTaxonImage(Taxon taxon, DescriptionBase<?> imageGallery, ImageFile imageFile) {
		Set<DescriptionElementBase> elementsToRemove = new HashSet<DescriptionElementBase>();
		
		Set<DescriptionElementBase> images = imageGallery.getElements();
		
		for(DescriptionElementBase descriptionElement : images){
			for(Media media : descriptionElement.getMedia()){
				for(MediaRepresentation representation : media.getRepresentations()){
					for(MediaRepresentationPart part : representation.getParts()){
						if(part.equals(imageFile)){
							elementsToRemove.add(descriptionElement);
						}
					}
				}
			}
		}	
		
		for(DescriptionElementBase descriptionElement : elementsToRemove){
			imageGallery.removeElement(descriptionElement);
		}		
	}
}