/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.model;

import java.util.HashMap;
import java.util.Set;

import org.eclipse.jface.preference.PreferenceConverter;
import org.eclipse.jface.resource.FontRegistry;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.editors.text.EditorsUI;


/**
 * @author n.hoffmann
 * @created 18.03.2009
 * @version 1.0
 */
public class Resources {
	
	private static Resources instance;
	
	public static Resources getInstance(){
		if(instance == null){
			instance = new Resources();
		}
		return instance;
	}
	
	
	/* ***************************************************************************************
		PREFERENCES
	************************************************************************************** */
	public static final String CODE_PREFERENCE = "code";
	//public static final NomenclaturalCode CODE_PREFERENCE_ICBN = NomenclaturalCode.ICBN();
	//public static final NomenclaturalCode CODE_PREFERENCE_ICZN = NomenclaturalCode.ICZN();
	//public static final NomenclaturalCode DEFAULT_CODE_PREFERENCE = CODE_PREFERENCE_ICZN;
	public static final String CODE_PREFERENCE_ICBN = "ICBN";
	public static final String CODE_PREFERENCE_ICZN = "ICZN";
	public static final String DEFAULT_CODE_PREFERENCE = CODE_PREFERENCE_ICBN;
	public static final String INITIALIZED = "initialized";
	public static final String INITIALIZE_W_TESTDATA = "init_w_testdata";
	
	/* ***************************************************************************************
		STRINGS
	************************************************************************************** */
	public static final String MISAPPLIED_NAME = "misappliedname";
	public static final String BASIONYM = "basionym";
	public static final String SYNONYM = "synonym";
	public static final String HOMOTYPIC_SYNONYM = "homotypic_synonym";
	public static final String HETEROTYPIC_SYNONYM = "heterotypic_synonym";
	public static final String NAMERELATION = "namerelation";
	public static final String TAXON = "taxon";
	public static final String HOMOTYPIC_GROUP = "homotypicgroup";
	public static final String QUICK_NAME_TAXON = "quick_name_taxon";
	public static final String PROPERTY_SHEET_CHANGE = "property_sheet_change";
	public static final String REFRESH_NAMEVIEWER = "refresh_name_viewer";
	
	/* ***************************************************************************************
	FONTS
	************************************************************************************** */	
	public static final String MENU_ITEM_ITALICS_FONT = "menu_item_italics_font";
	public static final String ACCEPTED_TAXON_FONT = "accepted_taxon_font";
	public static final String SYNONYM_FONT = "synonym_font";
	public static final String MISAPPLIEDNAME_FONT = "misappliedname_font";
	public static final String CONCEPT_FONT = "concept_font";
	public static final String DATASOURCE_FONT = "datasource_font";
	public static final String CHOOSE_NAME_TEXT_FONT = "choose_name_text_font";
	public static final String FONT_DEFAULT_PROMPT = "default_prompt_font";
	
	/* ***************************************************************************************
	COLORS
	************************************************************************************** */
	public static final String COLOR_COMPOSITE_BACKGROUND = "group_gray_background_color";
	public static final String PROP_SHEET_RED = "property_sheet_red";
	public static final String SEARCH_VIEW_FOREGROUND = "search_view_foreground";
	public static final String SEARCH_VIEW_FOCUS = "search_view_focus";
	public static final String COLOR_COMPOSITE_SELECTED = "color_list_selection";
	public static final String COLOR_LIST_BACKGROUND = "color_list_background";
	
	/* ***************************************************************************************
	PREFERENCES
	************************************************************************************** */
	public static final String FEATURE_PREFERENCE = "feature_preference";
	public static final String RANK_PREFERENCE = "rank_preference";


	/***************************************************************************
	 * FONT REGISTRY
	 **************************************************************************/
	private FontRegistry fontRegistry;

	private FontRegistry getFontRegistry() {
		if (fontRegistry == null) {
			fontRegistry = new FontRegistry(Display.getCurrent());

			fontRegistry.put(DATASOURCE_FONT,
					new FontData[] { new FontData("Arial", 8, SWT.NONE) });
			fontRegistry.put(MENU_ITEM_ITALICS_FONT,
					new FontData[] { new FontData("Arial", 9, SWT.ITALIC) });
			fontRegistry.put(ACCEPTED_TAXON_FONT,
					new FontData[] { new FontData("Georgia", 12, SWT.NONE) });
			fontRegistry.put(SYNONYM_FONT,
					new FontData[] { new FontData("Georgia", 10, SWT.NONE) });
			fontRegistry.put(MISAPPLIEDNAME_FONT,
					new FontData[] { new FontData("Georgia", 10, SWT.NONE) });
			fontRegistry.put(CONCEPT_FONT,
					new FontData[] { new FontData("Georgia", 10, SWT.NONE) });
			fontRegistry.put(CHOOSE_NAME_TEXT_FONT,
					new FontData[] { new FontData("Arial", 12, SWT.BOLD) });
			fontRegistry.put(FONT_DEFAULT_PROMPT,
					new FontData[] { new FontData("Georgia", 10, SWT.ITALIC) });
		}
		return fontRegistry;
	}

	public static Font getFont(String key) {
		return getInstance().getFontRegistry().get(key);
	}
	
	/**
	 * @param font
	 */
	public static Font italicizeFont(Font font) {
		FontData fontData = font.getFontData()[0];
		fontData.setStyle(fontData.getStyle() | SWT.ITALIC);
		Font italFont = new Font(Display.getDefault(), fontData);
		
		int i = 0;
		String fontName = "italic";
		Set<?> keySet = getInstance().getFontRegistry().getKeySet();
		while (keySet.contains(fontName + i)) {
			i++;
		}
		getInstance().getFontRegistry().put(fontName + i, italFont.getFontData());
		
		return italFont;
	}

	/***************************************************************************
	 * COLOR MAP
	 **************************************************************************/
	private static HashMap<String, Color> colorRegistry;
	
	public static Color getColor(String key) {
		return getInstance().getColorRegistry().get(key);
	}
	
	private HashMap<String, Color> getColorRegistry() {
		if (colorRegistry == null) {
			 colorRegistry = new HashMap<String, Color>();
			 
			 RGB currentLineRGB = PreferenceConverter.getColor(
					 EditorsUI.getPreferenceStore(), "currentLineColor");
			 Color currentLineColor = new Color(null, currentLineRGB);
			 			 
			 colorRegistry.put(COLOR_COMPOSITE_BACKGROUND,
					 new Color(null, 250, 250, 250));
			 colorRegistry.put(PROP_SHEET_RED,
					 new Color(null, 255, 0, 0));		
			 colorRegistry.put(SEARCH_VIEW_FOREGROUND,
					 new Color(null, 192, 192, 192));	
			 colorRegistry.put(SEARCH_VIEW_FOCUS,
					 new Color(null, 0, 0, 0));	
//			 colorRegistry.put(COLOR_COMPOSITE_SELECTED, 
//					 Display.getDefault().getSystemColor(SWT.COLOR_LIST_SELECTION));
			 colorRegistry.put(COLOR_COMPOSITE_SELECTED, 
					 currentLineColor);		 
			 colorRegistry.put(COLOR_LIST_BACKGROUND, 
					 Display.getDefault().getSystemColor(SWT.COLOR_LIST_BACKGROUND));
		}
		EditorsUI.getPreferenceStore();
		return colorRegistry;
	}
}
