/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.model;

import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author n.hoffmann
 * @created 25.03.2009
 * @version 1.0
 */
public class TaxonUtil {
	private static final Logger logger = Logger
		.getLogger(TaxonUtil.class);

	
	/**
	 * TODO error handling. throw exceptions if something goes wrong
	 * 
	 * @param taxonUuid
	 * @return
	 */
	public static boolean deleteTaxonBaseIsolated(UUID taxonUuid){
		// get a new conversation
		ConversationHolder conversation = CdmStore.NewTransactionalConversation();
		// find the taxonBase
		TaxonBase<?> taxonBase = CdmStore.getTaxonService().findByUuid(taxonUuid);
		// delete the taxonBase
		CdmStore.getTaxonService().delete(taxonBase);
		// commit the conversation and throw it away
		conversation.commit(true);
		return true;
	}
	
	public static Taxon addChildTaxonBaseIsolated(UUID taxonUuid, TaxonNameBase<?, ?> newTaxonName){
		// disallow saving of zero length names
		if(newTaxonName.getFullTitleCache().length() == 0){
			return null;
		}
		
		// get a new conversation
		ConversationHolder conversation = CdmStore.NewTransactionalConversation();
		// find the taxonBase
		Taxon parentTaxon = (Taxon) CdmStore.getTaxonService().findByUuid(taxonUuid);
		// logic to add new taxon name
		Taxon childTaxon = Taxon.NewInstance(newTaxonName, parentTaxon.getSec());
		parentTaxon.addTaxonomicChild(childTaxon, null, null);
		//not needed here: CdmStore.getTaxonService().save(parentTaxon);
		// commit the conversation and throw it away
		conversation.commit(true);
		return childTaxon;
	}
	
	public static boolean moveTaxonBaseIsolated(UUID taxonUuid, UUID newParentTaxonUuid){
		
		// get a new conversation
		ConversationHolder conversation = CdmStore.NewTransactionalConversation();
		// find the taxonBases
		Taxon taxon = (Taxon) CdmStore.getTaxonService().findByUuid(taxonUuid);
		Taxon newParentTaxon = (Taxon) CdmStore.getTaxonService().findByUuid(newParentTaxonUuid);
		
		Taxon oldParent = taxon.getTaxonomicParent();
		if (oldParent != null) {
			oldParent.removeTaxonomicChild(taxon);
		}
		
		newParentTaxon.addTaxonomicChild(taxon, null, null);
		conversation.commit(true);		
		return true;
	}
	
	/**
	 * TODO this method should be in cdm library
	 * 
	 * Example:
	 * TaxonA(fromTaxon) isOverlapping TaxonB(toTaxon) 
	 * 
	 * @param fromTaxon
	 * @param toTaxon
	 * @return
	 * @deprecated TODO this method should be in the library
	 */
	public static TaxonRelationship getRelationshipBetweenTwoTaxa(Taxon fromTaxon, Taxon toTaxon){
		Set<TaxonRelationship> relations = new HashSet<TaxonRelationship>();
		
		for(TaxonRelationship relation : fromTaxon.getRelationsFromThisTaxon()){
			if(relation.getToTaxon().equals(toTaxon)){
				relations.add(relation);
			}
		}
		
		if(relations.size() > 1){
			logger.warn("Found multiple relations between two taxa. Does this make sense?");
		}
		
		if(relations.size() == 0){
			logger.warn("No relations between the two given taxa");
			new Throwable("No relations between the two given taxa");
		}
		
		return relations.toArray(new TaxonRelationship[0])[0];
	}
	
	/**
	 * Returns true if <code>child</code> belongs to the children, grandchildren,
	 * etc. of <code>parent</code>.
	 * 
	 * @param child
	 * @param parent
	 * @return
	 */
	public static boolean isTaxonChildOfTaxon(Taxon child, Taxon parent) {
		
		// Traverse all checkTaxon's children
		for (Taxon childTaxon : parent.getTaxonomicChildren()) {
			
			if (childTaxon.equals(child)) {
				return true;
			} else {
				
				// Compare taxon with childTaxon's children
				if (isTaxonChildOfTaxon(child, childTaxon)) {
					return true;
				}
			}
		}
		return false;
	}
}
