/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.model;

import eu.etaxonomy.cdm.model.common.TimePeriod;

/**
 * @autor p.ciardelli
 * @author n.hoffmann
 * @created 18.03.2009
 * @version 1.0
 */
public class TimeUtil {
	/**
	 * Converts a <code>String</code> whose format is either a valid year 
	 * or two valid years with the format "XXXX-XXXX" into a TimePeriod. 
	 *
	 * @see #getValidYear(String yearStr)
	 * @param refYear
	 * @return
	 * @throws NumberFormatException
	 */
	public static TimePeriod convertTimePeriod(String refYear) throws NumberFormatException {
		
		if (refYear == null || ("").equals(refYear)){
			return null;
		}
		
		TimePeriod datePublished = TimePeriod.NewInstance();
		
		// In case format is "xxxx-xxxx"
		String[] years = refYear.split("-");

		// Unlikely case of "xxxx-xxxx-xxxx..."
		if (years.length > 2) {
			throw new NumberFormatException();
		}
		
		// Set startYear
		datePublished.setStartYear(getValidYear(years[0]));

		// Format is "xxxx-xxxx"
		if (years.length == 2) {
			datePublished.setEndYear(getValidYear(years[1]));
		}
		
		return datePublished;
	}
	
	/**
	 * Checks whether a <code>String</code> is a valid year between
	 * 1750 and 2030. Throws a <code>NumberFormatException</code> if not.
	 * 
	 * @param yearStr
	 * @return
	 * @throws NumberFormatException
	 */
	public static Integer getValidYear(String yearStr) throws NumberFormatException {
		
		Integer yearInt = null;
		
		// Try casting string - don't catch number format exception
		try {
			yearInt = new Integer(yearStr);
		} catch (ClassCastException e) {
			throw new NumberFormatException();
		}
		
		// Is year in valid range?
		if (yearInt < 1750 || yearInt > 2030) {
			throw new NumberFormatException();
		}
		
		return yearInt;
	}
}
