/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.operations.AbstractOperation;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;

import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * @author p.ciardelli
 * @created 14.01.2009
 * @version 1.0
 * @author n.hoffmann
 */
public abstract class AbstractPostOperation extends AbstractOperation {

	private static final Logger logger = Logger
			.getLogger(AbstractPostOperation.class);
	
	/**
	 * 
	 */
	protected IPostOperationEnabled postOperationEnabled;
	
	/** 
	 * A reference to the taxon the concrete operation is working on 
	 */
	protected Taxon taxon;

	/**
	 * 
	 * @param label
	 * @param undoContext
	 * @param taxon
	 */
	public AbstractPostOperation(String label, IUndoContext undoContext,
			Taxon taxon) {
		super(label);
		addContext(undoContext);
		
		this.taxon = taxon;
	}
	
	/**
	 * 
	 * @param label
	 * @param undoContext
	 * @param taxon
	 * @param postOperationEnabled
	 */
	public AbstractPostOperation(String label, IUndoContext undoContext,
			Taxon taxon, IPostOperationEnabled postOperationEnabled) {
		this(label, undoContext, taxon);
		this.postOperationEnabled = postOperationEnabled;
	}
	
	/**
	 * This method will try to call the post operation on a possibly registered
	 * IPostOperationEnabled implementor. Objects that were affected by the operation 
	 * may be passed to the registered IPostOperationEnabled implementor.
	 * 
	 * 
	 * @param objectAffectedByOperation the affected object. Should be <code>null</code> if not needed
	 * 
	 * @return
	 */
	protected IStatus postExecute(CdmBase objectAffectedByOperation) {	
		if(postOperationEnabled != null){
			logger.trace("executing post operation");
			return postOperationEnabled.postOperation(objectAffectedByOperation) ? Status.OK_STATUS : Status.CANCEL_STATUS;
		}
		return Status.OK_STATUS;
	}
}
