/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.name.HomotypicalGroup;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * Change the homotypical group of a given synonym.
 * 
 * @author n.hoffmann
 * @created 19.01.2009
 * @version 1.0
 */
public class ChangeHomotypicGroupOperation extends AbstractPostOperation {
	
	@SuppressWarnings("unused")
	private static final Logger logger = Logger
			.getLogger(ChangeHomotypicGroupOperation.class);

	/**
	 * The synonym to be moved.
	 */
	private Synonym synonym; 
	/**
	 * The former homotypical group the synonym belonged to
	 */
	private HomotypicalGroup oldHomotypicalGroup;
	/**
	 * The homotypical group the synonym is to be moved to
	 */
	private HomotypicalGroup newHomotypicalGroup;
	
	public ChangeHomotypicGroupOperation(String label, IUndoContext undoContext, 
			Taxon taxon, Synonym synonym, HomotypicalGroup newHomotypicalGroup, IPostOperationEnabled editor) {
		super(label, undoContext, taxon, editor);
		
		this.synonym = synonym;
		if(synonym == null){
			throw new IllegalArgumentException(
					"A null synonym was provided.");
		}
		
		this.oldHomotypicalGroup = synonym.getHomotypicGroup();
		this.newHomotypicalGroup = newHomotypicalGroup;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {

		// Get synonym name
		TaxonNameBase<?, ?> synonymName = this.synonym.getName();
		
		// TODO pass in homotypical group's taxon in case we are dragging from one editor to another
		
		// Switch groups
		oldHomotypicalGroup.removeTypifiedName(synonymName);
		newHomotypicalGroup.addTypifiedName(synonymName);		
		
		// Redraw editor if it exists
		return postExecute(synonym);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		// Get synonym name
		TaxonNameBase<?, ?> synonymName = this.synonym.getName();
		if(synonymName == null){
			// TODO
		}
		
		// TODO pass in homotypical group's taxon in case we are dragging from one editor to another
		
		// Switch groups
		newHomotypicalGroup.removeTypifiedName(synonymName);
		oldHomotypicalGroup.addTypifiedName(synonymName);		
		
		// Redraw editor if it exists
		return postExecute(synonym);
	}
}
