/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;

/**
 * @author p.ciardelli
 * @created 21.01.2009
 * @version 1.0
 * @author n.hoffmann
 */
public class ChangeSynonymToConceptOperation extends AbstractPostOperation {
	private Synonym synonym;
	private TaxonRelationshipType taxonRelationshipType;
	
	public ChangeSynonymToConceptOperation(String label,
			IUndoContext undoContext, Taxon taxon, Synonym synonym, TaxonRelationshipType taxonRelationshipType, IPostOperationEnabled postOperationEnabled) {
		super(label, undoContext, taxon, postOperationEnabled);
		
		this.taxonRelationshipType = taxonRelationshipType;
		this.synonym = synonym;
		
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		// Get name from synonym
		TaxonNameBase<?, ?> synonymName = synonym.getName();
		
		// remove synonym from taxon
		taxon.removeSynonym(synonym);
		
		// Create a taxon with synonym name
		Taxon fromTaxon = Taxon.NewInstance(synonymName, null);
		
		// Add taxon relation 
		fromTaxon.addTaxonRelation(taxon, taxonRelationshipType, null, null);
		
//		TaxonRelationshipType.
//		logger.warn("Not yet implemented.");
		
		return postExecute(fromTaxon);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return null;
	}
}
