// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.store.internal.TaxeditorStorePlugin;
import eu.etaxonomy.taxeditor.store.model.TaxonUtil;

/**
 * @author n.hoffmann
 * @created 08.05.2009
 * @version 1.0
 */
public class CreateChildTaxonOperation extends AbstractPostOperation {
	
	private static final Logger logger = Logger
	.getLogger(CreateChildTaxonOperation.class);
	
	private TaxonNameBase newTaxonName;

	private Taxon childTaxon;

	
	/**
	 * @param label
	 * @param undoContext
	 * @param parentTaxon
	 * @param postOperationEnabled
	 * @param conversationEnabled
	 */
	public CreateChildTaxonOperation(String label, IUndoContext undoContext,
			Taxon parentTaxon, TaxonNameBase name, IPostOperationEnabled postOperationEnabled) {
		super(label, undoContext, parentTaxon, postOperationEnabled);
		
		this.newTaxonName = name;
	}


	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		childTaxon = TaxonUtil.addChildTaxonBaseIsolated(taxon.getUuid(), newTaxonName);
		
		if(childTaxon != null){
			return postExecute(childTaxon);
		}else{
			return new Status(IStatus.ERROR, TaxeditorStorePlugin.PLUGIN_ID, TaxeditorStorePlugin.ERROR_SAVING_ZERO_NAME, "Attempt to save taxon with zero length name", null);
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		logger.warn("Not yet implemented.");
		return null;
	}
	
	public Taxon getChildTaxon() {
		return childTaxon;
	}
}
