/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.store.model.TaxonUtil;

/**
 * Change the taxonomic parent of a given taxon.
 * 
 * @author n.hoffmann
 * @created 16.01.2009
 * @version 1.0
 */
public class MoveTaxonOperation extends AbstractPostOperation {
	
	@SuppressWarnings("unused")
	private static final Logger logger = Logger.getLogger(MoveTaxonOperation.class);
	/**
	 * A reference to the new taxonomical parent.
	 */
	private Taxon newParentTaxon;
	/**
	 * A reference to the former taxonomical parent
	 */
	private Taxon oldParentTaxon;

	public MoveTaxonOperation(String label, IUndoContext undoContext,
			Taxon taxon, Taxon newParentTaxon) {
		super(label, undoContext, taxon);

		this.newParentTaxon = newParentTaxon;
		
		// Save old parent taxon for undo
		this.oldParentTaxon = taxon.getTaxonomicParent();
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		TaxonUtil.moveTaxonBaseIsolated(taxon.getUuid(), newParentTaxon.getUuid());
		
		return Status.OK_STATUS;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		TaxonUtil.moveTaxonBaseIsolated(taxon.getUuid(), oldParentTaxon.getUuid());
		
		return Status.OK_STATUS;
	}
}
