// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.eclipse.core.commands.ExecutionException;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * @author n.hoffmann
 * @created 07.04.2009
 * @version 1.0
 */
public class CreateMisapplicationOperationTest extends AbstractTaxeditorOperationTest {

	private static Taxon taxon;
	
	/**
	 * @throws java.lang.Exception
	 */
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		
		taxon = Taxon.NewInstance(null, null);
		
		operation = new CreateMisapplicationOperation("Create Misapplication", undoContext, taxon, postOperation);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.CreateMisapplicationOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testExecuteIProgressMonitorIAdaptable() throws ExecutionException {
		operation.execute(monitor, info);
		
		Assert.assertTrue("Taxon should have misapplications now.", taxon.getMisappliedNames().size() > 0);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.CreateMisapplicationOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testUndoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.undo(monitor, info);
		
		Assert.assertTrue("Taxon should not have misapplications now.", taxon.getMisappliedNames().size() == 0);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.CreateMisapplicationOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testRedoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.redo(monitor, info);
		
		Assert.assertTrue("Taxon should have misapplications now.", taxon.getMisappliedNames().size() > 0);
	}
}
