// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.eclipse.core.commands.ExecutionException;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.description.TextData;
import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * @author n.hoffmann
 * @created 08.04.2009
 * @version 1.0
 */
public class DeleteDescriptionElementOperationTest extends AbstractTaxeditorOperationTest {

	private static DescriptionElementBase descriptionElement;

	private static TaxonDescription description;
	
	/**
	 * @throws java.lang.Exception
	 */
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		taxon = Taxon.NewInstance(null, null);
		descriptionElement = TextData.NewInstance();
		
		description = TaxonDescription.NewInstance();
		
		description.addElement(descriptionElement);
		
		taxon.addDescription(description);
		
		
		operation = new DeleteDescriptionElementOperation("", undoContext, taxon, descriptionElement, postOperation);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteDescriptionElementOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testExecuteIProgressMonitorIAdaptable() throws ExecutionException {
		operation.execute(monitor, info);
		
		Assert.assertTrue(taxon.getDescriptions().toArray(new TaxonDescription[0])[0].getElements().size() == 0);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteDescriptionElementOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testUndoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.undo(monitor, info);
		
		Assert.assertTrue(taxon.getDescriptions().toArray(new TaxonDescription[0])[0].getElements().size() > 0);
		Assert.assertEquals(descriptionElement, taxon.getDescriptions().toArray(new TaxonDescription[0])[0].getElements().toArray(new DescriptionElementBase[0])[0]);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteDescriptionElementOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testRedoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.redo(monitor, info);
		
		Assert.assertTrue(taxon.getDescriptions().toArray(new TaxonDescription[0])[0].getElements().size() == 0);
	}
}
