// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * @author n.hoffmann
 * @created 08.04.2009
 * @version 1.0
 */
public class DeleteMisapplicationOperationTest extends AbstractTaxeditorOperationTest{
	private static final Logger logger = Logger
			.getLogger(DeleteMisapplicationOperationTest.class);

	private static Taxon taxon;

	private static Taxon misapplication;
	
	/**
	 * @throws java.lang.Exception
	 */
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		
		taxon = Taxon.NewInstance(null, null);
		misapplication = Taxon.NewInstance(null, null);
		
		taxon.addMisappliedName(misapplication, null, null);
		
		operation = new DeleteMisapplicationOperation("", undoContext, taxon, misapplication, postOperation);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteMisapplicationOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testExecuteIProgressMonitorIAdaptable() throws ExecutionException {
		operation.execute(monitor, info);
		
		Assert.assertTrue(taxon.getMisappliedNames().size() == 0);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteMisapplicationOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testUndoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.undo(monitor, info);
		
		Assert.assertEquals(misapplication, taxon.getMisappliedNames().toArray(new Taxon[0])[0]);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteMisapplicationOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testRedoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.redo(monitor, info);
		
		Assert.assertTrue(taxon.getMisappliedNames().size() == 0);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.AbstractPostOperation#postExecute(CdmBase)}.
	 */
	@Test
	public void testPostExecute() {
		// TODO there is not post operation functionality for this class
		// at the moment. Implement test when there is.
		logger.warn("No post operation functionality for this class");
	}
}
