// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.store.operations;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.SynonymRelationshipType;
import eu.etaxonomy.cdm.model.taxon.Taxon;

/**
 * @author n.hoffmann
 * @created 08.04.2009
 * @version 1.0
 */
public class DeleteSynonymOperationTest extends AbstractTaxeditorOperationTest{
	private static final Logger logger = Logger
			.getLogger(DeleteSynonymOperationTest.class);

	private static Synonym synonym;

	private static SynonymRelationshipType synonymRelationshipType;
	
	/**
	 * @throws java.lang.Exception
	 */
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		taxon = Taxon.NewInstance(null, null);
		synonym = Synonym.NewInstance(null, null);
		synonymRelationshipType = SynonymRelationshipType.SYNONYM_OF();
		
		taxon.addSynonym(synonym, synonymRelationshipType);
		
		operation = new DeleteSynonymOperation("", undoContext, taxon, synonym, postOperation);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteSynonymOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testExecuteIProgressMonitorIAdaptable() throws ExecutionException {
		operation.execute(monitor, info);
		
		Assert.assertTrue(taxon.getSynonyms().size() == 0);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteSynonymOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testUndoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.undo(monitor, info);
		
		Assert.assertTrue(taxon.getSynonyms().size() > 0);
		Assert.assertEquals(synonym, taxon.getSynonyms().toArray(new Synonym[0])[0]);
	}

	/**
	 * Test method for {@link eu.etaxonomy.taxeditor.store.operations.DeleteSynonymOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)}.
	 * @throws ExecutionException 
	 */
	@Test
	public void testRedoIProgressMonitorIAdaptable() throws ExecutionException {
		operation.redo(monitor, info);
		
		Assert.assertTrue(taxon.getSynonyms().size() == 0);
	}
}
